@@ -73,7 +73,7 @@ def ProcessFiles(sourceFile):
                 slicedApple = list(filter(lambda x: x != '' and x is not None, ymlRegex.split(sourceContent)))
                 for piece in slicedApple:
                     if not ymlRegex.fullmatch(piece):
-                        targetContent = [n + piece for n in targetContent]
+                        targetContent += piece
                     else:
                         localized = 'name: ' + Translate(piece[6:], langCombo).title()
                         targetContent += localized
@@ -89,15 +89,14 @@ def ProcessFiles(sourceFile):
                 for piece in slicedApple:
                     if mdRegex.fullmatch(piece):
                         if re.fullmatch(r'\]\(#.+\)', piece):
-                            anchors = Translate(' '.join(piece[3:-1].split('-')))
-                            for i in range(len(anchors)):
-                                targetContent[i] += '](#' + '-'.join(anchors[i].split(' ')).lower() + ')'
+                            anchor = Translate(' '.join(piece[3:-1].split('-')), langCombo)
+                            targetContent += '](#' + '-'.join(anchor.split(' ')).lower() + ')'
                         else:
-                            targetContent = [n + piece for n in targetContent]
+                            targetContent += piece
                     else:
                         localized = Translate(piece, langCombo)
                         targetContent += localized
-            file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[2:]), encoding = 'utf-8', mode = 'w+')
+            file = codecs.open(targetPaths[i] + '/' + '/'.join(sourceFile.split('/')[1:]), encoding = 'utf-8', mode = 'w+')
             file.write(targetContent)
             file.close()
         return
@@ -196,7 +195,7 @@ def root():
         re.purge
         exit()
     allModified = modifiedStaged + modifiedUnstaged
-    untrackedSrc = [n for n in repo.untracked_files and n.split('/')[1:] in sourceDir]
+    untrackedSrc = [n for n in repo.untracked_files if n.split('/')[1:] in os.listdir(sourceDir)]
     workTree = [n.a_blob.path for n in allModified if n.a_blob.path.split('/')[0] == '_'.join(sourceLang.split('-')).lower()] + untrackedSrc
 
 @root.command()
@@ -208,7 +207,7 @@ def diff():
     if workTree:
         PrYellow('\n The following files will be added or overwritten in target languages:')
         for doc in workTree:
-            if doc.split('/')[-1] in os.listdir(sourceDir + '/'.join(doc.split('/')[1:-1])):
+            if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
                 stats.append(FileStats(doc))
                 PrLightPurple(doc)
             else:
@@ -225,7 +224,7 @@ def diff():
         cont = input('\n Continue [c] or abort [Enter]? ')
         if cont == 'c':
             for doc in workTree:
-                if doc.split('/')[-1] in os.listdir(sourceDir + '/'.join(doc.split('/')[1:-1])):
+                if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
                     ProcessFiles(doc)
                 else:
                     for path in targetPaths:
